@@ -74,6 +74,24 @@ simulate <- function(input, no_of_sim = 10000, .data = NULL){
     }
   }
 
+  else if(!is.null(input_t1$hazard_treatment)){
+    if(!is.null(input_t1$hazard_control)){
+      input_t1$hazard_treatment <- input_t1$hazard_control
+    }
+    else{
+      if(!is.null(input_t1$h0)){
+        input_t1$h0 <- input_t1$h0 + 0.10
+      }
+      else{
+        input_t1$h0 <- 0.75
+      }
+    }
+    for(i in 1:no_of_sim){
+      output_power[[i]] <- do.call(survivalBACT, input)
+      output_type1[[i]] <- do.call(survivalBACT, input_t1)
+    }
+  }
+
   prob_ha <- output_power %>% map_dbl(c("post_prob_accept_alternative"))
   N_stop <- output_power %>% map_dbl(c("N_enrolled"))
   expect_success <- output_power %>% map_dbl(c("stop_expected_success"))
