@@ -7,6 +7,10 @@ test_that("The randomization is", {
   expect_equal(randomization(100, 100, c(3, 2)), check)
   set.seed(40555)
   expect_equal(sum(randomization(12, 10, c(3, 2)) == 1), 5)
+  expect_equal(sum(randomization(200, 21, c(3, 4))), 113)
+  expect_equal(sum(randomization(200, c(10, 20), c(1, 4)) == 0), 40)
   expect_error(randomization(20, 40, c(1, 4)))
   expect_error(randomization(100, 20, c(2, 1)))
+  expect_error(randomization(200, 4, c(1.5, 2.5)))
+  expect_error(randomization(20, 1.1, c(1, 4)))
 })
